@@ -1,8 +1,15 @@
+from logging.config import dictConfig
 from random import random
 from threading import Thread
 from time import sleep
 
-from the_spymaster_util import configure_logging, get_logger
+from the_spymaster_util.logger import get_dict_config, get_logger
+
+
+def configure_logging():
+    dict_config = get_dict_config()
+    dictConfig(dict_config)
+
 
 configure_logging()
 log = get_logger(__name__)
@@ -16,6 +23,7 @@ def worker(name: str):
 
 
 def main():
+    # TODO: Make this a test.
     log.update_context(shared=True)
     log.info("main")
     for i in range(5):
