@@ -1,7 +1,7 @@
 import threading
 from typing import Any, Callable, Iterable, Mapping, Optional
 
-from the_spymaster_util import get_logger
+from the_spymaster_util.logger import get_logger
 
 log = get_logger(__name__)
 
@@ -16,7 +16,7 @@ def _make_target_context_aware(target: Optional[Callable], parent_context: dict)
     def wrapper(*args, **kwargs):
         try:
             log.update_context(**parent_context)
-        except:  # noqa
+        except:  # noqa  # pylint: disable=bare-except
             pass
         return target(*args, **kwargs)
 
@@ -31,7 +31,7 @@ def context_aware_thread_init(  # noqa
     group=None,
     target: Optional[Callable] = None,
     name: Optional[str] = None,
-    args: Iterable[Any] = None,
+    args: Optional[Iterable[Any]] = None,
     daemon: bool = False,
     kwargs: Optional[Mapping[str, Any]] = None,
 ):
